@@ -10,28 +10,30 @@ from django.db import migrations
 class Migration(migrations.Migration):
 
     dependencies = [
-        ('admin_interface', '0011_add_environment_options'),
+        ("admin_interface", "0011_add_environment_options"),
     ]
 
     operations = [
         migrations.AlterField(
-            model_name='theme',
-            name='logo_color',
+            model_name="theme",
+            name="logo_color",
             field=colorfield.fields.ColorField(
                 blank=True,
-                default='#FFFFFF',
-                help_text='#FFFFFF',
+                default="#FFFFFF",
+                help_text="#FFFFFF",
                 max_length=10,
-                verbose_name='color'),
+                verbose_name="color",
+            ),
         ),
         migrations.AlterField(
-            model_name='theme',
-            name='title_color',
+            model_name="theme",
+            name="title_color",
             field=colorfield.fields.ColorField(
                 blank=True,
-                default='#F5DD5D',
-                help_text='#F5DD5D',
+                default="#F5DD5D",
+                help_text="#F5DD5D",
                 max_length=10,
-                verbose_name='color'),
+                verbose_name="color",
+            ),
         ),
     ]
