@@ -143,6 +143,16 @@ class Theme(models.Model):
     language_chooser_active = models.BooleanField(
         default=True, verbose_name=_("active")
     )
+    language_chooser_control_choices = (
+        ("default-select", _("Default Select")),
+        ("minimal-select", _("Minimal Select")),
+    )
+    language_chooser_control = models.CharField(
+        max_length=20,
+        choices=language_chooser_control_choices,
+        default="default-select",
+        verbose_name=_("control"),
+    )
     language_chooser_display_choices = (
         ("code", _("code")),
         ("name", _("name")),
@@ -321,12 +331,19 @@ class Theme(models.Model):
         default=True, verbose_name=_("close button visible")
     )
 
+    list_filter_highlight = models.BooleanField(
+        default=True, verbose_name=_("highlight active")
+    )
     list_filter_dropdown = models.BooleanField(
         default=True, verbose_name=_("use dropdown")
     )
     list_filter_sticky = models.BooleanField(
         default=True, verbose_name=_("sticky position")
     )
+    list_filter_removal_links = models.BooleanField(
+        default=False, verbose_name=_(
+            "quick remove links for active filters at top of sidebar")
+    )
 
     foldable_apps = models.BooleanField(default=True, verbose_name=_("foldable apps"))
 
